summaryrefslogtreecommitdiff
path: root/src/stringfilter_type.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/stringfilter_type.h')
-rw-r--r--src/stringfilter_type.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/stringfilter_type.h b/src/stringfilter_type.h
index 5ba8e876b..c2acffc35 100644
--- a/src/stringfilter_type.h
+++ b/src/stringfilter_type.h
@@ -47,9 +47,9 @@ private:
public:
/**
* Constructor for filter.
* @param case_sensitive Pointer to a (usually static) variable controlling the case-sensitivity. NULL means always case-insensitive.
*/
- StringFilter(const bool *case_sensitive = NULL) : filter_buffer(NULL), word_matches(0), case_sensitive(case_sensitive) {}
+ StringFilter(const bool *case_sensitive = nullptr) : filter_buffer(nullptr), word_matches(0), case_sensitive(case_sensitive) {}
~StringFilter() { free(this->filter_buffer); }
void SetFilterTerm(const char *str);
@@ -47,9 +47,9 @@ private:
/**
* Constructor for filter.
- * @param case_sensitive Pointer to a (usually static) variable controlling the case-sensitivity. NULL means always case-insensitive.
+ * @param case_sensitive Pointer to a (usually static) variable controlling the case-sensitivity. nullptr means always case-insensitive.
*/